@@ -47,6 +47,12 @@ def auth_path() -> Path:
     return neuralspace_home() / "auth.json"
 
 
+# FILE KEYS IN csv
+NLU_FILE = "nlu.csv"
+SYNONYMS_FILE = "synonym.csv"
+REGEX_FILE = "regex.csv"
+LOOKUP_FILE = "lookup.csv"
+
 # KEYS
 
 DESCRIPTION = "description"
@@ -83,6 +89,7 @@ EXAMPLE_ID = "exampleId"
 TEXT = "text"
 EXAMPLES = "examples"
 MODEL_NAME = "modelName"
+MODEL_ID_key = "model_id"
 MODEL_ID = "modelId"
 TRAINING_STATUS = "trainingStatus"
 COMPLETED = "Completed"
@@ -127,7 +134,12 @@ TRANSLITERATED_TEXT = "transliterated_text"
 SUGGESTIONS = "suggestions"
 DETECTED_LANGUAGES = "detected_languages"
 AUGMENTATION_SUGGESTIONS = "augmentation_suggestions"
-
+APP_TYPE = "appType"
+CODE = "code"
+END = "end"
+START = "start"
+CONFIDENCE = "confidence"
+INTENT_RANKING = "intent_ranking"
 # supported entity types
 NER_TYPES = [PRE_TRAINED, LOOKUP, SYNONYM, REGEX]
 
@@ -139,7 +151,6 @@ TRAIN_MODEL_COMMAND = "neuralspace nlu train --help"
 DEPLOY_MODEL_COMMAND = "neuralspace nlu deploy --help"
 PARSE_MODEL_COMMAND = "neuralspace nlu parse --help"
 
-
 # checking command
 
 APP_IS_INSTALLED = "App is already installed"
