@@ -19,14 +19,17 @@ from rich.text import Text as Text_render
 
 from neuralspace.apis import get_async_http_session
 from neuralspace.constants import (
+    APP_TYPE,
     ARROW_UP,
     AUTHORIZATION,
     BIN,
     BOLD_END,
     BOLD_START,
     BOOK,
+    CODE,
     COMMON_HEADERS,
     COMPLETED,
+    CONFIDENCE,
     COUNT,
     CREATE_PROJECT_COMMAND,
     CROSS,
@@ -36,8 +39,10 @@ from neuralspace.constants import (
     DEAD,
     DEPLOY_MODEL_COMMAND,
     DOWN_ARROW,
+    END,
     END_INDEX,
     ENTITIES,
+    ENTITY,
     ENTITY_ACC,
     ERROR,
     EXAMPLE,
@@ -54,6 +59,7 @@ from neuralspace.constants import (
     INTENT,
     INTENT_ACCURACY,
     INTENT_CLASSIFIER_METRICS,
+    INTENT_RANKING,
     KEY,
     LANGUAGE,
     LANGUAGES,
@@ -64,6 +70,7 @@ from neuralspace.constants import (
     MODEL_NAME,
     MODELS,
     N_REPLICAS,
+    NAME,
     NER_METRICS,
     NUMBER_OF_EXAMPLES,
     NUMBER_OF_INTENTS,
@@ -94,6 +101,7 @@ from neuralspace.constants import (
     SAVED,
     SEARCH,
     SOUP,
+    START,
     START_INDEX,
     TEXT,
     TIMED_OUT,
@@ -104,6 +112,7 @@ from neuralspace.constants import (
     TYPE,
     UPLOAD_DATASET_COMMAND,
     WRITING,
+    MODEL_ID_key,
     neuralspace_url,
 )
 from neuralspace.nlu.constants import (
@@ -155,9 +164,9 @@ async def get_languages() -> Dict[Text, Any]:
             console.print(f"> {INFO} {GREEN_TICK} Successfully Fetched Languages")
             table = Table()
             table.add_column("Language")
-            table.add_column("Code")
-            for row in json_response["data"]:
-                table.add_row(row["language"], row["code"])
+            table.add_column(CODE)
+            for row in json_response[DATA]:
+                table.add_row(row[LANGUAGE], row[CODE])
             console.print(table)
             console.print(
                 f"{FAST_FORWARD} To create the project: {DARK_ORANGE_START}{CREATE_PROJECT_COMMAND}{DARK_ORANGE_END}"
@@ -165,7 +174,7 @@ async def get_languages() -> Dict[Text, Any]:
         else:
             console.print(f"> {ERROR} {CROSS} Failed to create project")
             console.print(
-                f'''> Reason for failure {SAD_SMILEY}: " {RED_START}{json_response['message']}{RED_END} "'''
+                f'''> Reason for failure {SAD_SMILEY}: " {RED_START}{json_response[MESSAGE]}{RED_END} "'''
             )
     return json_response
 
@@ -192,20 +201,20 @@ async def create_project(project_name: Text, languages: List[Text]) -> Dict[Text
                 f"> {INFO} " f"{PERSON_HERE} Here is your project information..."
             )
             table.add_column("Name")
-            table.add_column("Language")
+            table.add_column(LANGUAGE)
             table.add_column("App Type")
             table.add_column("Project Id", style="green")
             language_to_write = ""
-            for i, language in enumerate(json_response[DATA]["language"]):
-                if i == len(json_response[DATA]["language"]) - 1:
+            for i, language in enumerate(json_response[DATA][LANGUAGE]):
+                if i == len(json_response[DATA][LANGUAGE]) - 1:
                     language_to_write += language
                 else:
                     language_to_write += language + ", "
             table.add_row(
-                json_response[DATA]["projectName"],
+                json_response[DATA][PROJECT_NAME],
                 language_to_write,
-                json_response[DATA]["appType"],
-                json_response[DATA]["projectId"],
+                json_response[DATA][APP_TYPE],
+                json_response[DATA][PROJECT_ID],
             )
             console.print(table)
             console.print(
@@ -239,7 +248,7 @@ async def delete_project(project_id: Text) -> Dict[Text, Any]:
         else:
             console.print(f"> {ERROR} {CROSS} Failed to delete projects")
             console.print(
-                f"> Reason for failure {SAD_SMILEY}:- {RED_START}{json_response['message']}{RED_END}"
+                f"> Reason for failure {SAD_SMILEY}:- {RED_START}{json_response[MESSAGE]}{RED_END}"
             )
     return json_response
 
@@ -295,7 +304,7 @@ async def list_projects(
         else:
             console.print(f"> {ERROR} {CROSS} Failed to list projects")
             console.print(
-                f'''> Reason for failure {SAD_SMILEY}: " {RED_START}{json_response['message']}{RED_END} "'''
+                f'''> Reason for failure {SAD_SMILEY}: " {RED_START}{json_response[MESSAGE]}{RED_END} "'''
             )
     return json_response
 
@@ -312,7 +321,19 @@ def print_examples_table(examples: Dict[Text, Any], verbose: bool = False):
         f"> {INFO} {NUMBERS_IN_SQUARE} Total Examples Count: {examples[DATA][COUNT]}"
     )
     for data in examples[DATA][EXAMPLES]:
-        args = [data[EXAMPLE_ID], data[TEXT]]
+        marked_sentence = ""
+        start_index = []
+        end_index = []
+        for i, entities in enumerate(data[ENTITIES]):
+            start_index.append(entities[START])
+            end_index.append(entities[END])
+        for idx, character in enumerate(data[TEXT]):
+            if idx in start_index:
+                marked_sentence += "[bold green]"
+            elif idx in end_index:
+                marked_sentence += "[/bold green]"
+            marked_sentence += character
+        args = [data[EXAMPLE_ID], marked_sentence]
         if verbose:
             args += [data[INTENT], str(len(data[ENTITIES]))]
         table.add_row(*args)
@@ -371,7 +392,7 @@ async def list_examples(
         else:
             console.print(f"> {ERROR} {CROSS} Failed to list examples")
             console.print(
-                f'''> Reason for failure {SAD_SMILEY}: " {RED_START}{json_response['message']}{RED_END} "'''
+                f'''> Reason for failure {SAD_SMILEY}: " {RED_START}{json_response[MESSAGE]}{RED_END} "'''
             )
 
     return json_response
@@ -474,7 +495,7 @@ async def list_models(
         else:
             console.print(f"> {ERROR} {CROSS} Failed to list models")
             console.print(
-                f'''> Reason for failure {SAD_SMILEY}: " {RED_START}{json_response['message']}{RED_END} "'''
+                f'''> Reason for failure {SAD_SMILEY}: " {RED_START}{json_response[MESSAGE]}{RED_END} "'''
             )
     return json_response
 
@@ -495,7 +516,7 @@ async def delete_examples(example_ids: List[Text]) -> Dict[Text, Any]:
         else:
             console.print(f"> {ERROR} {CROSS} Failed to delete examples")
             console.print(
-                f'''> Reason for failure {SAD_SMILEY}: " {RED_START}{json_response['message']}{RED_END} "'''
+                f'''> Reason for failure {SAD_SMILEY}: " {RED_START}{json_response[MESSAGE]}{RED_END} "'''
             )
     return json_response
 
@@ -566,7 +587,7 @@ async def upload_dataset(
                     f"> Failed on example: \n{json.dumps(example, indent=4, ensure_ascii=False)}"
                 )
                 console.print(
-                    f'''> Reason for failure {SAD_SMILEY}: " {RED_START}{json_response['message']}{RED_END} "'''
+                    f'''> Reason for failure {SAD_SMILEY}: " {RED_START}{json_response[MESSAGE]}{RED_END} "'''
                 )
                 error_examples.append(example)
                 if ignore_errors:
@@ -624,7 +645,7 @@ async def wait_till_training_completes(
                                 )
                             if json_response[DATA][TRAINING_STATUS] == FAILED:
                                 console.print(
-                                    f'''> Reason for failure {SAD_SMILEY}: " {RED_START}{json_response[DATA]['message']}{RED_END}\
+                                    f'''> Reason for failure {SAD_SMILEY}: " {RED_START}{json_response[DATA][MESSAGE]}{RED_END}\
                                      "'''
                                 )
                             break
@@ -632,7 +653,7 @@ async def wait_till_training_completes(
                         console.print(f"> {ERROR} Failed to fetch model details")
                         console.print(
                             f'''> Reason for failure {SAD_SMILEY}:
-                            " {RED_START}{json_response['message']}{RED_END} "'''
+                            " {RED_START}{json_response[MESSAGE]}{RED_END} "'''
                         )
                         break
                     status.update(f"Model is {current_status} {PERSON_STANDING}")
@@ -671,13 +692,13 @@ async def train_model(
         json_response = await response.json(encoding="utf-8")
         if is_success_status(response.status):
             console.print("> {INFO} Training job queued successfully")
-            model_id = json_response[DATA]["model_id"]
+            model_id = json_response[DATA][MODEL_ID_key]
             last_model_status = await wait_till_training_completes(
                 model_id, wait, wait_time
             )
         else:
             console.print(f"> {ERROR} Failed to queue training job")
-            console.print(f"> {ERROR} {json_response['message']}")
+            console.print(f"> {ERROR} {json_response[MESSAGE]}")
             last_model_status = None
     return json_response, last_model_status
 
@@ -701,7 +722,7 @@ async def delete_models(model_id: Text) -> Dict[Text, Any]:
         else:
             console.print(f"> {ERROR} {CROSS} Failed to delete models")
             console.print(
-                f'''> Reason for failure {SAD_SMILEY}: " {RED_START}{json_response['message']}{RED_END} "'''
+                f'''> Reason for failure {SAD_SMILEY}: " {RED_START}{json_response[MESSAGE]}{RED_END} "'''
             )
     return json_response
 
@@ -728,7 +749,7 @@ async def deploy(model_id: Text, n_replicas: int) -> Dict[Text, Any]:
         else:
             console.print(f"> {ERROR} {CROSS} Failed to deploy model")
             console.print(
-                f'''> Reason for failure {SAD_SMILEY}: " {RED_START}{json_response['message']}{RED_END} "'''
+                f'''> Reason for failure {SAD_SMILEY}: " {RED_START}{json_response[MESSAGE]}{RED_END} "'''
             )
     return json_response
 
@@ -740,9 +761,9 @@ def print_nlu_response(nlu_response: Dict[Text, Any], response_time: float):
     table.add_column("Intent Confidence")
     table.add_column("Response Time (sec)")
     table.add_row(
-        nlu_response[DATA]["text"],
-        nlu_response[DATA]["intent"]["name"],
-        str(nlu_response[DATA]["intent"]["confidence"]),
+        nlu_response[DATA][TEXT],
+        nlu_response[DATA][INTENT][NAME],
+        str(nlu_response[DATA][INTENT][CONFIDENCE]),
         str(response_time / 1000),
     )
     console.print(table)
@@ -752,7 +773,7 @@ def print_nlu_response(nlu_response: Dict[Text, Any], response_time: float):
     intent_ranking_table.add_column("Intent")
     intent_ranking_table.add_column("Confidence")
 
-    for row in nlu_response[DATA]["intent_ranking"]:
+    for row in nlu_response[DATA][INTENT_RANKING]:
         intent_ranking_table.add_row(
             row["name"],
             str(row["confidence"]),
@@ -760,12 +781,12 @@ def print_nlu_response(nlu_response: Dict[Text, Any], response_time: float):
     console.print(f"> {INFO} Intent Ranking")
     console.print(intent_ranking_table)
     formatted_entities = []
-    for e in nlu_response["data"]["entities"]:
-        e[START_INDEX] = e["start"]
-        e[END_INDEX] = e["end"]
-        e[TYPE] = e["entity"]
+    for e in nlu_response[DATA][ENTITIES]:
+        e[START_INDEX] = e[START]
+        e[END_INDEX] = e[END]
+        e[TYPE] = e[ENTITY]
         formatted_entities.append(e)
-    print_ner_response(formatted_entities, nlu_response["data"]["text"])
+    print_ner_response(formatted_entities, nlu_response[DATA][TEXT])
 
 
 async def parse(model_id: Text, input_text: Text) -> Dict[Text, Any]:
@@ -791,6 +812,6 @@ async def parse(model_id: Text, input_text: Text) -> Dict[Text, Any]:
         else:
             console.print(f"> {ERROR} {CROSS} Failed to parse model")
             console.print(
-                f'''> Reason for failure {SAD_SMILEY}: " {RED_START}{json_response['message']}{RED_END} "'''
+                f'''> Reason for failure {SAD_SMILEY}: " {RED_START}{json_response[MESSAGE]}{RED_END} "'''
             )
     return json_response
