@@ -159,6 +159,7 @@ def converter(
     data_type: Text,
     output_path: Text,
     ignore_missing_examples: bool,
+    ignore_swapped_columns: bool,
 ):
     if entity_mapping is not False:
         if from_platform == "rasa":
@@ -197,6 +198,7 @@ def converter(
                 entity_mapping=entity_mapping,
                 auto_tag_entities=auto_tag_entities,
                 ignore_missing_examples=ignore_missing_examples,
+                ignore_swapped_columns=ignore_swapped_columns,
             )
             converter.convert(
                 input_path=Path(input_path[0]),
