@@ -12,7 +12,6 @@ DEPLOY_MODEL_URL = "api/nlu/v1/model/deploy"
 DELETE_MODELS_URL = "api/nlu/v1/model"
 PARSE_URL = "api/nlu/v1/model/parse"
 
-
 TRAINING_PROGRESS = [
     "Initiated",
     "Queued",
@@ -84,9 +83,39 @@ SUPPORTED_LANGUAGES = [
     "ro",
     "ru",
     "es",
+    "sq",
+    "an",
+    "az",
+    "ba",
+    "bs",
+    "br",
+    "my",
+    "ce",
+    "cv",
+    "ka",
+    "ht",
+    "is",
+    "io",
+    "jv",
+    "ky",
+    "lb",
+    "mk",
+    "mg",
+    "ms",
+    "ne",
+    "oc",
+    "su",
+    "sw",
+    "tl",
+    "tg",
+    "tt",
+    "uz",
+    "vo",
+    "cy",
+    "yo",
+    "multilingual",
 ]
 
-
 # Training status colour codes
 C_INITIATED = "⚪"
 C_QUEUED = "🔵"
