@@ -34,6 +34,10 @@ class DataConverter:
     ):
         NotImplementedError("lookup converter is not implemented")
 
+    @staticmethod
+    def count(dataset):
+        return len(dataset)
+
     @staticmethod
     def save_converted_data(
         output_directory: Path,
