@@ -1,5 +1,5 @@
 from pathlib import Path
-from typing import Any, Dict, List, Text
+from typing import Any, Dict, List, Optional, Text
 
 from rasa.shared.nlu.training_data.training_data import TrainingData
 
@@ -9,6 +9,7 @@ from neuralspace.constants import (
     ENTITY,
     ENTITY_TYPE,
     EXAMPLES,
+    INTENT,
     LANGUAGE,
     LOOKUP,
     NAME,
@@ -30,7 +31,10 @@ from neuralspace.nlu.utils import (
 
 class RasaConverter(DataConverter):
     def __init__(
-        self, language: Text, entity_mapping: Dict[Text, Text], auto_tag_entities: bool
+        self,
+        language: Text,
+        entity_mapping: Optional[Dict[Text, Text]],
+        auto_tag_entities: bool,
     ):
         self.nlu_data = []
         self.lookup_data = []
@@ -39,6 +43,8 @@ class RasaConverter(DataConverter):
         self.language = language
         self.entity_mapping = entity_mapping
         self.auto_tag_entities = auto_tag_entities
+        self.number_of_nlu_examples_before_duplicate_check = 0
+        self.number_of_nlu_examples_after_duplicate_check = 0
 
     @property
     def all_entity_types(self) -> List[Text]:
@@ -129,6 +135,37 @@ class RasaConverter(DataConverter):
             formatted_nlu_data.append(example.as_dict())
         return formatted_nlu_data
 
+    def number_of_unique_intent(self):
+        return len(set([example[INTENT] for example in self.nlu_data]))
+
+    def post_process(self, dataset_type, output_directory):
+        if self.entity_mapping:
+            self.nlu_data = map_entities(self.nlu_data, self.entity_mapping)
+        if self.auto_tag_entities:
+            self.nlu_data = auto_tag_pretrained_entities(self.nlu_data, self.language)
+            self.nlu_data = auto_tag_lookup(self.nlu_data, self.lookup_data)
+            self.nlu_data = auto_tag_regex(self.nlu_data, self.regex_data)
+        self.number_of_nlu_examples_before_duplicate_check = self.count(self.nlu_data)
+        self.nlu_data = remove_nlu_duplicates(self.nlu_data)
+        self.number_of_nlu_examples_after_duplicate_check = self.count(self.nlu_data)
+        self.lookup_data = remove_entity_duplicates(
+            remove_nlu_duplicates(self.lookup_data)
+        )
+        self.regex_data = remove_entity_duplicates(
+            remove_nlu_duplicates(self.regex_data)
+        )
+        self.synonym_data = remove_entity_duplicates(
+            remove_nlu_duplicates(self.synonym_data)
+        )
+        self.set_data_type(dataset_type)
+        self.save_converted_data(
+            output_directory=output_directory,
+            nlu_data=self.nlu_data,
+            lookup_data=self.lookup_data,
+            synonym_data=self.synonym_data,
+            regex_data=self.regex_data,
+        )
+
     def convert(
         self, input_path: List[Path], output_directory: Path, dataset_type: DatasetType
     ):
@@ -143,30 +180,4 @@ class RasaConverter(DataConverter):
             self.regex_data += self.__regex_converter(data.regex_features)
             self.synonym_data += self.__synonym_converter(data.entity_synonyms)
 
-        if self.entity_mapping:
-            self.nlu_data = map_entities(self.nlu_data, self.entity_mapping)
-
-        if self.auto_tag_entities:
-            self.nlu_data = auto_tag_pretrained_entities(self.nlu_data, self.language)
-            self.nlu_data = auto_tag_lookup(self.nlu_data, self.lookup_data)
-            self.nlu_data = auto_tag_regex(self.nlu_data, self.regex_data)
-
-        self.set_data_type(dataset_type)
-        self.nlu_data = remove_nlu_duplicates(self.nlu_data)
-        self.lookup_data = remove_entity_duplicates(
-            remove_nlu_duplicates(self.lookup_data)
-        )
-        self.regex_data = remove_entity_duplicates(
-            remove_nlu_duplicates(self.regex_data)
-        )
-        self.synonym_data = remove_entity_duplicates(
-            remove_nlu_duplicates(self.synonym_data)
-        )
-        output_directory.mkdir(parents=True, exist_ok=True)
-        self.save_converted_data(
-            output_directory=output_directory,
-            nlu_data=self.nlu_data,
-            lookup_data=self.lookup_data,
-            synonym_data=self.synonym_data,
-            regex_data=self.regex_data,
-        )
+        self.post_process(dataset_type=dataset_type, output_directory=output_directory)
